<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 * @return array An array of default values
 */

function music_freak_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$music_freak_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fd2d55',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> false,
		'nav_search_enable'				=> true,
		'nav_social_enable'				=> false,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'music-freak-pro' ), '[the-year]', '[site-link]' ) . esc_html__( ' All Rights Reserved | ', 'music-freak-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'music-freak-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,about,playlist,music_video,service,testimonial,counter,promotion,blog,cta',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'music-freak-pro' ),
		'read_more_text' 				=> esc_html__( 'Read Full Article', 'music-freak-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_title'				=> esc_html__( 'Play All', 'music-freak-pro' ),
		'slider_alt_btn_title'			=> esc_html__( 'View All', 'music-freak-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Music is composed and performed!!', 'music-freak-pro' ),
		'about_subtitle'				=> esc_html__( 'About Us', 'music-freak-pro' ),
		'about_description'				=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'music-freak-pro' ),
		'about_btn_title'				=> esc_html__( 'Read More', 'music-freak-pro' ),

		// Playlist
		'playlist_section_enable'		=> true,
		'playlist_title'				=> esc_html__( 'Music for you', 'music-freak-pro' ),
		'playlist_btn_title'			=> esc_html__( 'Show More', 'music-freak-pro' ),

		// music video
		'music_video_section_enable'	=> true,
		'music_video_title'				=> esc_html__( 'Recently Played', 'music-freak-pro' ),
		'music_video_btn_title'			=> esc_html__( 'Show More', 'music-freak-pro' ),
		'music_video_list_title'		=> esc_html__( 'Trending Videos', 'music-freak-pro' ),
		'music_video_list_btn_title'	=> esc_html__( 'Show More', 'music-freak-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_sub_title'				=> esc_html__( 'Services', 'music-freak-pro' ),
		'service_title'					=> esc_html__( 'We provide melodious services to you', 'music-freak-pro' ),
		'service_btn_title'				=> esc_html__( 'More Services', 'music-freak-pro' ),
		'service_content_type'			=> 'category',
		'service_count'					=> 4,
		'service_column'				=> 'col-4',

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_image'				=> get_template_directory_uri() . '/assets/uploads/testimonial-bg.jpg',


		// counter
		'counter_section_enable'		=> false,

		// Promotion
		'promotion_section_enable'		=> true,
		'promotion_content_type'		=> 'page',
		'promotion_title'				=> esc_html__( 'Music is an art form, and opinions come into play.', 'music-freak-pro' ),
		'promotion_subtitle'			=> esc_html__( 'Featured', 'music-freak-pro' ),
		'promotion_description'			=> esc_html__( 'Music is an art form and cultural activity whose medium is sound organized in time. General definitions of music include common elements such as pitch, rhythm, dynamics, and the sonic qualities of timbre and texture. The word derived from greek.', 'music-freak-pro' ),
		'promotion_btn_title'			=> esc_html__( 'Try Free Now', 'music-freak-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 7,
		'blog_title'					=> esc_html__( 'Our Latest Blog', 'music-freak-pro' ),
		'blog_subtitle'					=> esc_html__( 'Check our blog, resources and more', 'music-freak-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Posts', 'music-freak-pro' ),

		// Call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'Join Instantly with $0 cost and get your song right now.', 'music-freak-pro' ),
		'cta_subtitle'					=> esc_html__( 'Join Our Community', 'music-freak-pro' ),
		'cta_btn_title'					=> esc_html__( 'Read More', 'music-freak-pro' ),

	);

	$output = apply_filters( 'music_freak_pro_default_theme_options', $music_freak_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}