<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'music_freak_pro_service_section', array(
	'title'             => esc_html__( 'Services','music-freak-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'music-freak-pro' ),
	'panel'             => 'music_freak_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'music_freak_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Freak_Pro_Switch_Control( $wp_customize, 'music_freak_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_service_section',
	'on_off_label' 		=> music_freak_pro_switch_options(),
) ) );

// service sub title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_service_section',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_freak_pro_theme_options[service_sub_title]', array(
		'selector'            => '#featured-services .section-header p.section-subtitle',
		'settings'            => 'music_freak_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_freak_pro_service_sub_title_partial',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_service_section',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_freak_pro_theme_options[service_title]', array(
		'selector'            => '#featured-services .section-header h2.section-title',
		'settings'            => 'music_freak_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_freak_pro_service_title_partial',
    ) );
}

// service btn title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_service_section',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_freak_pro_theme_options[service_btn_title]', array(
		'selector'            => '#featured-services .section-header a.btn',
		'settings'            => 'music_freak_pro_theme_options[service_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_freak_pro_service_btn_title_partial',
    ) );
}

// service btn url setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_service_section',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'type'				=> 'url',
) );

// Service column type control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_column]', array(
	'default'          	=> $options['service_column'],
	'sanitize_callback' => 'music_freak_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_column]', array(
	'label'             => esc_html__( 'Column', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'choices'			=> array( 
		'col-2' 		=> esc_html__( 'Two Column', 'music-freak-pro' ),
		'col-3' 		=> esc_html__( 'Three Column', 'music-freak-pro' ),
		'col-4' 		=> esc_html__( 'Four Column', 'music-freak-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'music_freak_pro_sanitize_number_range',
	'validate_callback' => 'music_freak_pro_validate_service_count',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'music-freak-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_service_section',
	'active_callback'   => 'music_freak_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'music_freak_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_freak_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'music-freak-pro' ),
		'post' 		=> esc_html__( 'Post', 'music-freak-pro' ),
		'category' 	=> esc_html__( 'Category', 'music-freak-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Icon_Picker( $wp_customize, 'music_freak_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_service_section',
		'active_callback'	=> 'music_freak_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_service_section',
		'choices'			=> music_freak_pro_page_choices(),
		'active_callback'	=> 'music_freak_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_service_section',
		'choices'			=> music_freak_pro_post_choices(),
		'active_callback'	=> 'music_freak_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Customize_Horizontal_Line( $wp_customize, 'music_freak_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'music_freak_pro_service_section',
			'active_callback' => 'music_freak_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_freak_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'music_freak_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_freak_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-freak-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_freak_pro_is_service_section_content_category_enable'
) ) );
